local MAJOR_VERSION = "LibDogTag-2.0"
local MINOR_VERSION = tonumber(("$Revision: 59952 $"):match("%d+")) or 0

if MINOR_VERSION > _G.DogTag_MINOR_VERSION then
	_G.DogTag_MINOR_VERSION = MINOR_VERSION
end

DogTag_funcs[#DogTag_funcs+1] = function()

local L = DogTag.L

DogTag:AddTag("CastName", {
	[[value = DogTag___castData[${unit}].displayName]],
	ret = "string;nil",
	events = "Cast",
	globals = "DogTag.__castData",
	doc = L["Return the current or last spell to be cast"],
	example = ('[CastName] => %q'):format("Holy Light"),
	category = L["Casting"]
})

DogTag:AddTag("CastTarget", {
	[[value = DogTag___castData[${unit}].target]],
	ret = "string;nil",
	events = "Cast",
	globals = "DogTag.__castData",
	doc = L["Return the current cast target name"],
	example = ('[CastTarget] => %q'):format((UnitName("player"))),
	category = L["Casting"]
})

DogTag:AddTag("CastTarget", {
	[[value = DogTag___castData[${unit}].rank]],
	ret = "number;nil",
	events = "Cast",
	globals = "DogTag.__castData",
	doc = L["Return the current cast rank"],
	example = '[CastRank] => "4"; [CastRank:Romanize] => "IV"',
	category = L["Casting"]
})

DogTag:AddTag("CastStartTime", {
	[[value = DogTag___castData[${unit}].startTime]],
	ret = "number;nil",
	events = "Cast",
	globals = "DogTag.__castData",
	doc = L["Return the time the current cast started"],
	example = ('[CastStartTime] => "%s"'):format(GetTime() - 3),
	category = L["Casting"]
})

DogTag:AddTag("CastEndTime", {
	[[value = DogTag___castData[${unit}].endTime]],
	ret = "number;nil",
	events = "Cast",
	globals = "DogTag.__castData",
	doc = L["Return the time the current cast is meant to finish"],
	example = ('[CastEndTime] => "%s"'):format(GetTime() - 2),
	category = L["Casting"]
})

DogTag:AddTag("CastDelay", {
	[[value = DogTag___castData[${unit}].delay]],
	ret = "number;nil",
	events = "Cast",
	globals = "DogTag.__castData",
	doc = L["Return the number of seconds the current cast has been delayed by interruption"],
	example = '[CastDelay] => "1.49997"; [CastDelay:Round(1)] => "1.5"',
	category = L["Casting"]
})

DogTag:AddTag("CastIsChanneling", {
	([[value = not DogTag___castData[${unit}].casting and %q]]):format(L["True"]),
	ret = "string;nil",
	events = "Cast",
	globals = "DogTag.__castData",
	doc = L["Return True if the current cast is a channeling spell"],
	example = ('[CastIsChanneling] => %q; [CastIsChanneling] => ""'):format(L["True"]),
	category = L["Casting"]
})

DogTag:AddTag("CastStopTime", {
	[[value = DogTag___castData[${unit}].stopTime]],
	ret = "number;nil",
	events = "Cast",
	globals = "DogTag.__castData",
	doc = L["Return the time which the current cast stopped, blank if not stopped yet"],
	example = ('[CastStopTime] => "%s"; [CastIsChanneling] => ""'):format(GetTime()-2),
	category = L["Casting"]
})

DogTag:AddTag("CastStopMessage", {
	[[value = DogTag___castData[${unit}].stopMessage]],
	ret = "string;nil",
	events = "Cast",
	globals = "DogTag.__castData",
	doc = L["Return the message as to why the cast stopped, if there is an error"],
	example = ('[CastStopMessage] => %q; [CastStopMessage] => %q, [CastStopMessage] => ""'):format(_G.FAILED, _G.INTERRUPTED),
	category = L["Casting"]
})

end
